.. _doc.modules:

=======================
Frequently Used Modules
=======================

In this section, we introduce some of the most frequently used modules. See
:ref:`reference` for their APIs and other modules in KLIFF.



**Quick links**

.. list-table::

    * - :ref:`doc.models`
      - :ref:`doc.dataset`
    * - :ref:`doc.calculators`
      - :ref:`doc.loss`

.. note::
    See also :ref:`reference`.

.. toctree::
    :caption: List of All Modules
    :maxdepth: 2

    dataset
    models
    descriptors
    calculators
    loss

